@@ -46,12 +46,12 @@ class KnotCollector(object):
         self.collect_zone_serial = collect_zone_serial
 
     def convert_state_time(time):
-        if time == "pending" or time == "running" or time == "frozen":
+        if time.startswith(("pending", "running", "frozen")):
             return 0
         elif time == "not scheduled" or time == "-":
             return None
         else:
-            match = re.match("([+-])((\d+)D)?((\d+)h)?((\d+)m)?((\d+)s)?", time)
+            match = re.match(r"([+-])((\d+)D)?((\d+)h)?((\d+)m)?((\d+)s)?", time)
             seconds = -1 if match.group(1) == '-' else 1
             if match.group(3):
                 seconds = seconds + 86400 * int(match.group(3))
