@@ -1,4 +1,4 @@
-/*  Copyright (C) 2023 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2024 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@ typedef struct {
 	unsigned n;                   /*!< Active fds. */
 	unsigned size;                /*!< Array size (allocated). */
 	void **ctx;                   /*!< Context for each fd. */
+	void **ctx2;                  /*!< Another context for each fd. */
 	time_t *timeout;              /*!< Timeout for each fd (seconds precision). */
 #if defined(HAVE_EPOLL) || defined(HAVE_KQUEUE)
 #ifdef HAVE_EPOLL
@@ -270,6 +271,16 @@ inline static void *fdset_it_get_ctx(const fdset_it_t *it)
 	return it->set->ctx[fdset_it_get_idx(it)];
 }
 
+/*!
+ * \brief Get a read/write pointer on (void *) second context.
+ */
+inline static void **fdset_ctx2(const fdset_t *set, const unsigned idx)
+{
+	assert(set && idx < set->n);
+
+	return &set->ctx2[idx];
+}
+
 /*!
  * \brief Move iterator on next received event.
  *
