@@ -22,50 +22,51 @@
 #define CTL_FLAG_FORCE			"F"
 #define CTL_FLAG_BLOCKING		"B"
 
-#define CTL_FLAG_DIFF_ADD		"+"
-#define CTL_FLAG_DIFF_REM		"-"
+#define CTL_FILTER_DIFF_ADD_R		"+"
+#define CTL_FILTER_DIFF_REM_R		"-"
 
-#define CTL_FLAG_LIST_SCHEMA		"s"
-#define CTL_FLAG_LIST_TXN		"t"
-#define CTL_FLAG_LIST_ZONES		"z"
+#define CTL_FILTER_LIST_SCHEMA		"s"
+#define CTL_FILTER_LIST_TXN		"t"
+#define CTL_FILTER_LIST_ZONES		"z"
 
-#define CTL_FLAG_STATUS_EMPTY		"e"
-#define CTL_FLAG_STATUS_SLAVE		"s"
-#define CTL_FLAG_STATUS_MEMBER		"m"
-#define CTL_FLAG_STATUS_UNIXTIME	"u"
+#define CTL_FILTER_FLUSH_OUTDIR		"d"
 
-#define CTL_FILTER_FLUSH_OUTDIR		'd'
+#define CTL_FILTER_STATUS_ROLE		"r"
+#define CTL_FILTER_STATUS_SERIAL	"s"
+#define CTL_FILTER_STATUS_TRANSACTION	"t"
+#define CTL_FILTER_STATUS_FREEZE	"f"
+#define CTL_FILTER_STATUS_CATALOG	"c"
+#define CTL_FILTER_STATUS_EVENTS	"e"
+#define CTL_FILTER_STATUS_UNIXTIME	"u"
+#define CTL_FILTER_STATUS_EMPTY_R	"e"
+#define CTL_FILTER_STATUS_SLAVE_R	"s"
+#define CTL_FILTER_STATUS_MEMBER_R	"m"
 
-#define CTL_FILTER_STATUS_ROLE		'r'
-#define CTL_FILTER_STATUS_SERIAL	's'
-#define CTL_FILTER_STATUS_TRANSACTION	't'
-#define CTL_FILTER_STATUS_FREEZE	'f'
-#define CTL_FILTER_STATUS_CATALOG	'c'
-#define CTL_FILTER_STATUS_EVENTS	'e'
+#define CTL_FILTER_PURGE_EXPIRE		"e"
+#define CTL_FILTER_PURGE_ZONEFILE	"f"
+#define CTL_FILTER_PURGE_JOURNAL	"j"
+#define CTL_FILTER_PURGE_TIMERS		"t"
+#define CTL_FILTER_PURGE_KASPDB		"k"
+#define CTL_FILTER_PURGE_CATALOG	"c"
+#define CTL_FILTER_PURGE_ORPHAN		"o"
 
-#define CTL_FILTER_PURGE_EXPIRE		'e'
-#define CTL_FILTER_PURGE_ZONEFILE	'f'
-#define CTL_FILTER_PURGE_JOURNAL	'j'
-#define CTL_FILTER_PURGE_TIMERS		't'
-#define CTL_FILTER_PURGE_KASPDB		'k'
-#define CTL_FILTER_PURGE_CATALOG	'c'
-#define CTL_FILTER_PURGE_ORPHAN		'o'
+#define CTL_FILTER_BACKUP_OUTDIR	"d"
+#define CTL_FILTER_BACKUP_ZONEFILE	"z"
+#define CTL_FILTER_BACKUP_NOZONEFILE	"Z"
+#define CTL_FILTER_BACKUP_JOURNAL	"j"
+#define CTL_FILTER_BACKUP_NOJOURNAL	"J"
+#define CTL_FILTER_BACKUP_TIMERS	"t"
+#define CTL_FILTER_BACKUP_NOTIMERS	"T"
+#define CTL_FILTER_BACKUP_KASPDB	"k"
+#define CTL_FILTER_BACKUP_NOKASPDB	"K"
+#define CTL_FILTER_BACKUP_KEYSONLY	"o"
+#define CTL_FILTER_BACKUP_NOKEYSONLY	"O"
+#define CTL_FILTER_BACKUP_CATALOG	"c"
+#define CTL_FILTER_BACKUP_NOCATALOG	"C"
+#define CTL_FILTER_BACKUP_QUIC		"q"
+#define CTL_FILTER_BACKUP_NOQUIC	"Q"
 
-#define CTL_FILTER_BACKUP_OUTDIR	'd'
-#define CTL_FILTER_BACKUP_ZONEFILE	'z'
-#define CTL_FILTER_BACKUP_NOZONEFILE	'Z'
-#define CTL_FILTER_BACKUP_JOURNAL	'j'
-#define CTL_FILTER_BACKUP_NOJOURNAL	'J'
-#define CTL_FILTER_BACKUP_TIMERS	't'
-#define CTL_FILTER_BACKUP_NOTIMERS	'T'
-#define CTL_FILTER_BACKUP_KASPDB	'k'
-#define CTL_FILTER_BACKUP_NOKASPDB	'K'
-#define CTL_FILTER_BACKUP_KEYSONLY	'o'
-#define CTL_FILTER_BACKUP_NOKEYSONLY	'O'
-#define CTL_FILTER_BACKUP_CATALOG	'c'
-#define CTL_FILTER_BACKUP_NOCATALOG	'C'
-#define CTL_FILTER_BACKUP_QUIC		'q'
-#define CTL_FILTER_BACKUP_NOQUIC	'Q'
+#define CTL_FILTER_BEGIN_BENEVOLENT	"b"
 
 #define STATUS_EMPTY			"-"
 
