@@ -153,11 +153,11 @@ knot_time_t knot_get_next_zone_key_event(const zone_keyset_t *keyset);
 /*!
  * \brief Returns DS record rdata for given key.
  *
- * This function caches the results, so caaling again with the same key returns immediately.
+ * This function caches the results, so calling again with the same key returns immediately.
  *
  * \param for_key         The key to compute DS for.
  * \param digesttype      DS digest algorithm.
- * \param out_donotfree   Output: the DS record rdata. Do not call dnssec_binry_free() on this ever.
+ * \param out_donotfree   Output: the DS record rdata. Do not call dnssec_binary_free() on this ever.
  *
  * \return Error code, KNOT_EOK if successful.
  */
@@ -202,3 +202,12 @@ void zone_sign_ctx_free(zone_sign_ctx_t *ctx);
  */
 int dnssec_key_from_rdata(dnssec_key_t **key, const knot_dname_t *owner,
                           const uint8_t *rdata, size_t rdlen);
+
+/*!
+ * \brief Tell if apex SOA is signed by all active ZSKs.
+ *
+ * \param keyset        Zone key set.
+ * \param apex_rrsig    Apex RRSIG RRSet.
+ */
+int is_soa_signed_by_all_zsks(const zone_keyset_t *keyset,
+                              const knot_rdataset_t *apex_rrsig);
